==> Blind-src-V2.43.zip: Blind-2.43/cmds/h.c <==
static char *rcsid = "$Header: /silver/homes/zeus/Blind-2.43/cmds/RCS/h.c,v 2.43 1995/03/20 01:43:09 zeus Exp zeus $";

/*
 *
 * $Log: h.c,v $
 * Revision 2.43  1995/03/20  01:43:09  zeus
 * *** empty log message ***
 *
 *
 */

#define NOTIMEB
 
#include "../protos/common.h"
#include "../protos/prototypes.h"
#include "../protos/cmds.h"
#include "../protos/cmds-g.h"
#include "../protos/enterturn-g.h"

extern char tbuf[];
extern int pos;
extern player *players;
extern char err_tmp[];

void

#ifdef V3
h_cmd (char *buf, player * P)
#else
g_cmd (char *buf, player * P)
#endif

{
  player *P2;
  alliance *a;
  defensive *d;

  hstrcpy (tbuf, buf);
  pos = 0;
  (void) next_token ();

  P2 = ninputplayer ();
  if (P2)
    if (P2 == P)		/* do this with everyone */
    {
      for (P2 = players; P2; P2 = P2->next)
	if (P2 != P)
	{
	  for (a = P->allies; a; a = a->next)
	    if (a->ally == P2)
	      removelist (&P->allies, a);
	  for (d = P->defend; d; d = d->next)
	    if (d->defend == P2)
	      break;
	  if (!d)
	  {
	    d = alloc (sizeof (defensive));
	    d->defend = P2;
	    addlist (&P->defend, d);
	  }
	}			/* end of inner "if not self" test */
    }				/* end of outer "if not self" test */
    else
    {
      for (a = P->allies; a; a = a->next)
	if (a->ally == P2)
	  removelist (&P->allies, a);
      for (d = P->defend; d; d = d->next)
	if (d->defend == P2)
	  break;
      if (!d)
      {
	d = alloc (sizeof (defensive));
	d->defend = P2;
	addlist (&P->defend, d);
      }
    }
  else
  {
    error (err_tmp);
  }
  extra_token ();
}

==> Blind-src-V2.44.zip: Blind-2.44/cmds/h.c <==
static char *rcsid = "$Header: /silver/homes/zeus/Blind-2.44/cmds/RCS/h.c,v 2.44 1995/12/31 19:45:18 zeus Exp zeus $";

/*
 *
 * $Log: h.c,v $
 * Revision 2.44  1995/12/31  19:45:18  zeus
 * *** empty log message ***
 *
 * Revision 2.43  1995/03/20  01:43:09  zeus
 *
 */

#define NOTIMEB
 
#include "../protos/common.h"
#include "../protos/prototypes.h"
#include "../protos/cmds.h"
#include "../protos/cmds-g.h"
#include "../protos/enterturn-g.h"

extern char tbuf[];
extern int pos;
extern player *players;
extern char err_tmp[];

#ifdef V3
void h_cmd_rcsid (void);
void
h_cmd_rcsid (void)
#else
void g_cmd_rcsid (void);
void
g_cmd_rcsid (void)
#endif
{
  printf ("%s\n",rcsid);
}

void

#ifdef V3
h_cmd (char *buf, player * P)
#else
g_cmd (char *buf, player * P)
#endif

{
  player *P2;
  alliance *a, *a2;
  defensive *d;

  hcstrcpy (tbuf, buf);
  pos = 0;
  (void) next_token ();

  P2 = ninputplayer ();
  if (P2)
    if (P2 == P)		/* do this with everyone */
    {
      for (P2 = players; P2; P2 = P2->next)
	if (P2 != P)
	{
	  for (a = P->allies; a; a=a2)
          {
            a2 = a->next;
	    if (a->ally == P2)
	      removelist (&P->allies, a);
          }
	  for (d = P->defend; d; d = d->next)
	    if (d->defend == P2)
	      break;
	  if (!d)
	  {
	    d = alloc (sizeof (defensive));
	    d->defend = P2;
	    addlist (&P->defend, d);
	  }
	}			/* end of inner "if not self" test */
    }				/* end of outer "if not self" test */
    else
    {
      for (a = P->allies; a; a=a2)
      {
        a2 = a->next;
	if (a->ally == P2)
	  removelist (&P->allies, a);
      }
      for (d = P->defend; d; d = d->next)
	if (d->defend == P2)
	  break;
      if (!d)
      {
	d = alloc (sizeof (defensive));
	d->defend = P2;
	addlist (&P->defend, d);
      }
    }
  else
  {
    error (err_tmp);
  }
  extra_token ();
}
